import React, { forwardRef, useRef } from 'react';
import cn from 'classnames';
import { useFocus } from '@alfalab/hooks';
import mergeRefs from 'react-merge-refs';
import CheckedIcon from '@alfalab/icons-classic/TickXsWhiteIcon';
import IndeterminateIcon from '@alfalab/icons-classic/CheckIndeterminateSWhiteIcon';

var styles = {"component":"checkbox__component_1gqa8","start":"checkbox__start_1gqa8","center":"checkbox__center_1gqa8","addons":"checkbox__addons_1gqa8","block":"checkbox__block_1gqa8","box":"checkbox__box_1gqa8","s":"checkbox__s_1gqa8","disabled":"checkbox__disabled_1gqa8","checked":"checkbox__checked_1gqa8","indeterminate":"checkbox__indeterminate_1gqa8","label":"checkbox__label_1gqa8","hint":"checkbox__hint_1gqa8","focused":"checkbox__focused_1gqa8","content":"checkbox__content_1gqa8","indeterminateIcon":"checkbox__indeterminateIcon_1gqa8"};
require('./index.css')

const Checkbox = forwardRef(({ checked, label, hint, size = 's', align = 'start', addons, block, onChange, className, name, disabled, dataTestId, indeterminate = false, ...restProps }, ref) => {
    const labelRef = useRef(null);
    const [focused] = useFocus(labelRef, 'keyboard');
    const handleChange = (event) => {
        if (onChange) {
            onChange(event, { checked: event.target.checked, name });
        }
    };
    return (
    // eslint-disable-next-line jsx-a11y/label-has-associated-control
    React.createElement("label", { className: cn(styles.component, styles[size], styles[align], className, {
            [styles.disabled]: disabled,
            [styles.checked]: checked,
            [styles.indeterminate]: indeterminate,
            [styles.focused]: focused,
            [styles.block]: block,
        }), ref: mergeRefs([labelRef, ref]) },
        React.createElement("span", { className: styles.box },
            React.createElement("input", Object.assign({ type: 'checkbox', onChange: handleChange, disabled: disabled, checked: checked, "data-test-id": dataTestId }, restProps)),
            checked && React.createElement(CheckedIcon, null),
            indeterminate && !checked && (React.createElement(IndeterminateIcon, { className: styles.indeterminateIcon }))),
        (label || hint) && (React.createElement("span", { className: styles.content },
            label && React.createElement("span", { className: styles.label }, label),
            hint && React.createElement("span", { className: styles.hint }, hint))),
        addons && React.createElement("span", { className: styles.addons }, addons)));
});
/**
 * Для отображения в сторибуке
 */
Checkbox.defaultProps = {
    indeterminate: false,
};

export { Checkbox };
